<?php

/**
 * 	CHERRY CHECKOUT - PHP SDK
 * 	Sample.php
 *
 *	A working script to create and update order through Cherry Checkout API.
 * 	Just replace YOUR_PUBLIC_KEY and YOUR_PRIVATE_KEY by your keys.
 * 	(available in your dashboard at https://dashboard.cherrycheckout.com )
 *
 * 	author:			Alex Potot
 * 	last update:	2017-08-09
 * 	copyright:		Cherry Checkout SA
 * 	website:		https://www.cherrycheckout.com
 * 	support:		support@cherrycheckout.com
 * 	doc:			https://developers.cherrycheckout.com/en/sdks/php
 */

// Include the SDK loader
require_once('../lib/cherrycheckout.php');

use CherryCheckout\Api;
use CherryCheckout\Customer;
use CherryCheckout\Me;
use CherryCheckout\Order;

use CherryCheckout\Exceptions\CustomerEmailMissingException;
use CherryCheckout\Exceptions\CustomerNotSetException;
use CherryCheckout\Exceptions\NoCharityAvailableException;
use CherryCheckout\Exceptions\OrderNotFoundException;
use CherryCheckout\Exceptions\TrackIdAlreadyExistsException;
use CherryCheckout\Exceptions\TrackIdMissingException;

$apiEndPoint = "https://api.cherrycheckout.com/v2";

// Set your keys
$publicKey = "YOUR_PUBLIC_KEY";
$secretKey = "YOUR_PRIVATE_KEY";

// Create your API instance
$api = new Api($apiEndPoint, $publicKey, $secretKey);

try {
	// Make the first call to see if our configuration is good
	$me = $api->getMe();
	echo "Configuration is ok !<br />\r\n";
}
catch (\Exception $ex) {
	echo "There was an error making first API call : " . $ex->getMessage() . "<br />\r\n";
}

// First, create a customer object
$customer = new Customer();
$customer
	->setFirstname('Michael')
	->setLastname('Jackson')
	->setBirthday('1958-08-29')
	->setEmail('kingofpop@mjcompany.com')
	->setGender('m')
	->setAddress('55 rue de la république')
	->setZipCode('75000')
	->setCity('Paris')
	->setCountry('France');

// Then, create an order object
$order = new Order();
$order
	->setOrderPrice(85.90)
	->setCherryPrice(2)
	->setTrackId('ODR-5736')
	->setCurrency('chf')
	->setCustomer($customer)
	->setStatus('validated');

// Finally, try to send the order to API
try {
	$api->createOrder($order);
	echo "Ok, order successfully created!<br />\r\n";
}
catch(CustomerEmailMissingException $ex) {
	echo "Error, customer e-mail was missing.<br />\r\n";
}
catch(CustomerNotSetException $ex) {
	echo "Error, customer was missing.<br />\r\n";
}
catch(NoCharityAvailableException $ex) {
	echo "Error, no charity available.<br />\r\n";
}
catch(TrackIdAlreadyExistsException $ex) {
	echo "Error, this track id already exists.<br />\r\n";
}
catch(\Exception $ex) {
	echo "Unknown error: " . $ex->getMessage() . "<br />\r\n";
}


// Create a new order object, in order to update it
$order = new Order();
$order
	->setTrackId('ODR-5736')
	->setStatus('canceled')
	->setOrderPrice(95.90);

// Try to update the order to API
try {
	$api->updateOrder($order);
	echo "Ok, order successfully updated!<br />\r\n";
}
catch(TrackIdMissingException $ex) {
	echo "Error, the track id was not set.<br />\r\n";
}
catch(OrderNotFoundException $ex) {
	echo "Error, order was not found with that track id.<br />\r\n";
}
catch(\Exception $ex) {
	echo "Unknown error: " . $ex->getMessage() . "<br />\r\n";
}